/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import Component from 'metal-component';
import Soy from 'metal-soy';
import {Config} from 'metal-state';

import templates from './VideoPreviewer.soy';

/**
 * Component that create an video player
 * @review
 */
class VideoPreviewer extends Component {}

/**
 * State definition.
 * @review
 * @static
 * @type {!Object}
 */
VideoPreviewer.STATE = {
	/**
	 * The "poster" attribute of the <video> element
	 * @instance
	 * @memberof VideoPreviewer
	 * @review
	 * @type {String}
	 */
	videoPosterURL: Config.string(),

	/**
	 * List of of video sources
	 * @instance
	 * @memberof VideoPreviewer
	 * @review
	 * @type {!Array<object>}
	 */
	videoSources: Config.arrayOf(
		Config.shapeOf({
			type: Config.string().required(),
			url: Config.string().required()
		})
	).required()
};

Soy.register(VideoPreviewer, templates);
export {VideoPreviewer};
export default VideoPreviewer;
